Input

pub struct Input {
    pub periodStart: FHIRDate,
    pub periodEnd: FHIRDate,
    pub measure: Option<FHIRString>,
    pub subject: Option<FHIRString>,
    pub practitioner: Option<FHIRString>,
    pub lastReceivedOn: Option<FHIRDateTime>,
}

Fields

periodStart: FHIRDate

The start of the measurement period. In keeping with the semantics of the date parameter used in the FHIR search operation, the period will start at the beginning of the period implied by the supplied timestamp. E.g. a value of 2014 would set the period s

periodEnd: FHIRDate

The end of the measurement period. The period will end at the end of the period implied by the supplied timestamp. E.g. a value of 2014 would set the period end to be 2014-12-31T23:59:59 inclusive

measure: Option<FHIRString>

The measure to evaluate. This parameter is only required when the operation is invoked on the resource type, it is not used when invoking the operation on a Measure instance

subject: Option<FHIRString>

Subject for which the measure will be collected. If not specified, measure data will be collected for all subjects that meet the requirements of the measure. If specified, the measure will only be calculated for the referenced subject(s)

practitioner: Option<FHIRString>

Practitioner for which the measure will be collected. If specified, measure data will be collected only for subjects that have a primary relationship to the identified practitioner

lastReceivedOn: Option<FHIRDateTime>

The date the results of this measure were last received. This parameter used to indicate when the last time data for this measure was collected. This information is used to support incremental data collection scenarios